.. ga4gh-client documentation master file, created by
   sphinx-quickstart on Tue Oct 11 07:21:12 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: _static/logo_ga.png

========================================
GA4GH Client Implementation
========================================

`ga4gh-client <https://pypi.python.org/pypi/ga4gh-client>`_ is a package that contains the client functionality of the `ga4gh <https://pypi.python.org/pypi/ga4gh>`_ package.

See the documentation for the ``ga4gh`` package on its `readthedocs page <https://readthedocs.org/projects/ga4gh-reference-implementation/>`_.

Contents:

.. toctree::
    :maxdepth: 2

    api
    status
